@@ -35,15 +35,14 @@ import org.broad.igv.Globals;
 import org.broad.igv.feature.Locus;
 import org.broad.igv.feature.RegionOfInterest;
 import org.broad.igv.feature.genome.GenomeManager;
-import org.broad.igv.ga4gh.Ga4ghAPIHelper;
-import org.broad.igv.ga4gh.OAuthUtils;
+import org.broad.igv.google.Ga4ghAPIHelper;
+import org.broad.igv.google.OAuthUtils;
 import org.broad.igv.prefs.Constants;
 import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.renderer.DataRange;
 import org.broad.igv.sam.AlignmentTrack;
 import org.broad.igv.track.RegionScoreType;
 import org.broad.igv.track.Track;
-import org.broad.igv.track.TrackProperties;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.event.DataLoadedEvent;
 import org.broad.igv.event.IGVEventBus;
@@ -378,11 +377,11 @@ public class CommandExecutor {
 
 
         String genomePath = genomeID;
-        if (!ParsingUtils.pathExists(genomePath)) {
+        if (!ParsingUtils.fileExists(genomePath)) {
             String workingDirectory = System.getProperty("user.dir", "");
             genomePath = FileUtils.getAbsolutePath(genomeID, workingDirectory);
         }
-        if (ParsingUtils.pathExists(genomePath)) {
+        if (ParsingUtils.fileExists(genomePath)) {
             try {
                 GenomeManager.getInstance().loadGenome(genomePath, null);
             } catch (IOException e) {
@@ -930,7 +929,9 @@ public class CommandExecutor {
             return AlignmentTrack.SortOption.FIRST_OF_PAIR_STRAND;
         } else if (str.equalsIgnoreCase("mateChr")) {
             return AlignmentTrack.SortOption.MATE_CHR;
-        } else {
+        } else if (str.equalsIgnoreCase("readOrder")) {
+            return AlignmentTrack.SortOption.READ_ORDER;
+        }else {
             try {
                 return AlignmentTrack.SortOption.valueOf(str.toUpperCase());
             } catch (IllegalArgumentException e) {
