@@ -220,10 +220,10 @@ public class GFFCodec extends AsciiFeatureCodec<Feature> {
         int end;
         int col = 3;
         try {
-            start = Integer.parseInt(tokens[col]) - 1;
+            start = (int)Double.parseDouble(tokens[col]) - 1;
             if (start < 0) throw new ParserException("Start index must be 1 or larger; GFF is 1-based", -1, line);
             col++;
-            end = Integer.parseInt(tokens[col]);
+            end = (int) Double.parseDouble(tokens[col]);
         } catch (NumberFormatException ne) {
             String msg = String.format("Column %d must contain a numeric value. %s", col + 1, ne.getMessage());
             throw new ParserException(msg, -1, line);
@@ -253,24 +253,12 @@ public class GFFCodec extends AsciiFeatureCodec<Feature> {
             }
         }
 
-        // Column 8 is phase for gff3,  frame for gff2.
+        // Column 8 is phase for gff3 and gtf.  Column is ambiguous for the deprecated GFF2 format,
+        // so translation is not supported.
         String phaseString = tokens[7].trim();
-        if (!phaseString.equals(".")) {
+        if (!phaseString.equals(".") && version != Version.GFF2) {
             int phaseOrFrame = Integer.parseInt(phaseString);
-            int frame;
-
-            if (version == Version.GFF3) {
-                frame = (3 - phaseOrFrame) % 3;
-            } else if (version == Version.GFF2) {
-                frame = phaseOrFrame;
-            } else {   // GTF
-                if(gencode) {
-                    frame = (3 - phaseOrFrame) % 3;   // GTF format is not consistent, GENCODE files use phase for column 8,  spec for gff2/gtf says this should be frame
-                } else {
-                    frame = phaseOrFrame;
-                }
-            }
-
+            int frame = (3 - phaseOrFrame) % 3;
             f.setReadingFrame(frame);
         }
 
@@ -512,8 +500,6 @@ public class GFFCodec extends AsciiFeatureCodec<Feature> {
                         value = StringUtils.decodeURL(value);
                     }
                     kvalues.put(StringUtils.intern(key), value);
-                } else {
-                    log.info("No attributes: " + description);
                 }
             }
         }
