@@ -32,8 +32,8 @@ import org.broad.igv.feature.Locus;
 import org.broad.igv.feature.RegionOfInterest;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.genome.GenomeListItem;
-import org.broad.igv.ui.commandbar.GenomeListManager;
 import org.broad.igv.feature.genome.GenomeManager;
+import org.broad.igv.google.GoogleUtils;
 import org.broad.igv.lists.GeneList;
 import org.broad.igv.lists.GeneListManager;
 import org.broad.igv.renderer.ColorScale;
@@ -44,6 +44,7 @@ import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.TrackFilter;
 import org.broad.igv.ui.TrackFilterElement;
 import org.broad.igv.ui.color.ColorUtilities;
+import org.broad.igv.ui.commandbar.GenomeListManager;
 import org.broad.igv.ui.panel.FrameManager;
 import org.broad.igv.ui.panel.ReferenceFrame;
 import org.broad.igv.ui.panel.TrackPanel;
@@ -255,10 +256,10 @@ public class IGVSessionReader implements SessionReader {
                         GenomeManager.getInstance().loadGenome(item.getPath(), null);
                     } else {
                         String genomePath = genomeId;
-                        if (!ParsingUtils.pathExists(genomePath)) {
+                        if (!ParsingUtils.fileExists(genomePath)) {
                             genomePath = FileUtils.getAbsolutePath(genomeId, rootPath);
                         }
-                        if (ParsingUtils.pathExists(genomePath)) {
+                        if (ParsingUtils.fileExists(genomePath)) {
                             GenomeManager.getInstance().loadGenome(genomePath, null);
 
                         } else {
@@ -463,8 +464,6 @@ public class IGVSessionReader implements SessionReader {
 
             for (final ResourceLocator locator : dataFiles) {
 
-                final String suppliedPath = locator.getPath();
-
                 Runnable runnable = () -> {
 
                     List<Track> tracks = null;
@@ -501,12 +500,12 @@ public class IGVSessionReader implements SessionReader {
                     }
                 };
 
-                boolean isAlignment = locator.getPath().endsWith(".bam") || locator.getPath().endsWith(".entries") ||
-                        locator.getPath().endsWith(".sam");
-
+                String path = locator.getPath();
+                boolean isAlignment = path != null && (path.endsWith(".bam") || path.endsWith(".entries") || path.endsWith(".sam"));
+                boolean isGoogle = GoogleUtils.isGoogleURL(path);
 
                 // Run synchronously if in batch mode or if there are no "track" elments, or if this is an alignment file
-                if (isAlignment || Globals.isBatch() || !hasTrackElments) {
+                if (isAlignment || isGoogle || Globals.isBatch() || !hasTrackElments) {
                     synchronousLoads.add(runnable);
                 } else {
                     Thread t = new Thread(runnable);
@@ -583,13 +582,7 @@ public class IGVSessionReader implements SessionReader {
             }
         }
 
-        if (rootPath == null) {
-            log.error("Null root path -- this is not expected");
-            MessageUtils.showMessage("Unexpected error loading session: null root path");
-            return;
-        }
-
-        String absolutePath = "ga4gh".equals(type) ? path : FileUtils.getAbsolutePath(path, rootPath);
+        String absolutePath = (rootPath == null || "ga4gh".equals(type)) ? path : FileUtils.getAbsolutePath(path, rootPath);
 
         fullToRelPathMap.put(absolutePath, path);
 
