@@ -44,9 +44,9 @@ import org.broad.igv.feature.GisticFileParser;
 import org.broad.igv.feature.MutationTrackLoader;
 import org.broad.igv.feature.ShapeFileUtils;
 import org.broad.igv.feature.basepair.BasePairTrack;
-import org.broad.igv.feature.bedpe.BedPEFeature;
-import org.broad.igv.feature.bedpe.BedPEParser;
-import org.broad.igv.feature.bedpe.InteractionTrack;
+import org.broad.igv.bedpe.BedPEFeature;
+import org.broad.igv.bedpe.BedPEParser;
+import org.broad.igv.bedpe.InteractionTrack;
 import org.broad.igv.feature.bionano.SMAPParser;
 import org.broad.igv.feature.bionano.SMAPRenderer;
 import org.broad.igv.feature.dranger.DRangerParser;
@@ -60,10 +60,10 @@ import org.broad.igv.feature.sprite.ClusterTrack;
 import org.broad.igv.feature.tribble.CodecFactory;
 import org.broad.igv.feature.tribble.FeatureFileHeader;
 import org.broad.igv.feature.tribble.TribbleIndexNotFoundException;
-import org.broad.igv.ga4gh.Ga4ghAPIHelper;
-import org.broad.igv.ga4gh.OAuthUtils;
 import org.broad.igv.goby.GobyAlignmentQueryReader;
 import org.broad.igv.goby.GobyCountArchiveDataSource;
+import org.broad.igv.google.Ga4ghAPIHelper;
+import org.broad.igv.google.GoogleUtils;
 import org.broad.igv.gwas.GWASData;
 import org.broad.igv.gwas.GWASParser;
 import org.broad.igv.gwas.GWASTrack;
@@ -72,7 +72,9 @@ import org.broad.igv.lists.GeneListManager;
 import org.broad.igv.maf.MultipleAlignmentTrack;
 import org.broad.igv.methyl.MethylTrack;
 import org.broad.igv.prefs.PreferencesManager;
-import org.broad.igv.renderer.*;
+import org.broad.igv.renderer.HeatmapRenderer;
+import org.broad.igv.renderer.MutationRenderer;
+import org.broad.igv.renderer.PointsRenderer;
 import org.broad.igv.sam.*;
 import org.broad.igv.sam.reader.IndexNotFoundException;
 import org.broad.igv.tdf.TDFDataSource;
@@ -90,7 +92,6 @@ import org.broad.igv.variant.VariantTrack;
 import org.broad.igv.variant.util.PedigreeUtils;
 
 import java.io.IOException;
-import java.net.MalformedURLException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -119,6 +120,11 @@ public class TrackLoader {
     public List<Track> load(ResourceLocator locator, Genome genome) throws DataLoadException {
 
         final String path = locator.getPath().trim();
+
+        if (GoogleUtils.isGoogleDrive(path) || GoogleUtils.isGoogleCloud(path)) {
+            GoogleUtils.checkLogin();
+        }
+
         log.info("Loading resource, path " + path);
         try {
             String typeString = locator.getTypeString();
@@ -176,15 +182,9 @@ public class TrackLoader {
                 loadGobyCountsArchive(locator, newTracks, genome);
             } else if (WiggleParser.isWiggle(locator)) {
                 loadWigFile(locator, newTracks, genome);
-            } else if (typeString.endsWith(".maf")) {
-                if (MutationTrackLoader.isMutationAnnotationFile(locator)) {
-                    loadMutFile(locator, newTracks, genome); // Must be tried before generic "loadIndexed" below
-                } else {
-                    loadMultipleAlignmentTrack(locator, newTracks, genome);
-                }
             } else if (typeString.endsWith(".maf.dict")) {
                 loadMultipleAlignmentTrack(locator, newTracks, genome);
-            }  else if (typeString.endsWith("mage-tab") || ExpressionFileParser.parsableMAGE_TAB(locator)) {
+            } else if (typeString.endsWith("mage-tab") || ExpressionFileParser.parsableMAGE_TAB(locator)) {
                 locator.setDescription("MAGE_TAB");
                 loadGctFile(locator, newTracks, genome);
             } else if (typeString.endsWith(".db") || typeString.endsWith(".dbn")) {
@@ -206,12 +206,16 @@ public class TrackLoader {
                 loadSMAPFile(locator, newTracks, genome);
             } else if (typeString.endsWith("dsi")) {
                 loadDSIFile(locator, newTracks, genome);
-            } else if (typeString.endsWith("bedpe")) {
+            } else if (typeString.endsWith("bedpe") || typeString.endsWith("_clusters")) {
                 loadBedPEFile(locator, newTracks, genome);
             } else if (typeString.endsWith("clusters")) {
                 loadClusterFile(locator, newTracks, genome);
             } else if (CodecFactory.hasCodec(locator, genome) && !forceNotTribble(typeString)) {
                 loadTribbleFile(locator, newTracks, genome);
+            } else if (MutationTrackLoader.isMutationAnnotationFile(locator)) {
+                loadMutFile(locator, newTracks, genome); // Must be tried before ".maf" test below
+            } else if (typeString.endsWith(".maf")) {
+                loadMultipleAlignmentTrack(locator, newTracks, genome);
             } else if (AttributeManager.isSampleInfoFile(locator)) {
                 // This might be a sample information file.
                 AttributeManager.getInstance().loadSampleInfo(locator);
@@ -219,27 +223,29 @@ public class TrackLoader {
                 MessageUtils.showMessage("<html>Unknown file type: " + path + "<br>Check file extension");
             }
 
+
             // Track line
-            TrackProperties tp = null;
-            String trackLine = locator.getTrackLine();
-            if (trackLine != null) {
-                tp = new TrackProperties();
-                ParsingUtils.parseTrackLine(trackLine, tp);
-            }
+            if (newTracks.size() > 0) {
+                TrackProperties tp = null;
+                String trackLine = locator.getTrackLine();
+                if (trackLine != null) {
+                    tp = new TrackProperties();
+                    ParsingUtils.parseTrackLine(trackLine, tp);
+                }
 
-            for (Track track : newTracks) {
-
-                if (locator.getFeatureInfoURL() != null) {
-                    track.setUrl(locator.getFeatureInfoURL());
-                }
-                if (tp != null) {
-                    track.setProperties(tp);
-                }
-                if (locator.getColor() != null) {
-                    track.setColor(locator.getColor());
-                }
-                if (locator.getSampleId() != null) {
-                    track.setSampleId(locator.getSampleId());
+                for (Track track : newTracks) {
+                    if (locator.getFeatureInfoURL() != null) {
+                        track.setUrl(locator.getFeatureInfoURL());
+                    }
+                    if (tp != null) {
+                        track.setProperties(tp);
+                    }
+                    if (locator.getColor() != null) {
+                        track.setColor(locator.getColor());
+                    }
+                    if (locator.getSampleId() != null) {
+                        track.setSampleId(locator.getSampleId());
+                    }
                 }
             }
 
@@ -257,7 +263,7 @@ public class TrackLoader {
         return typeString.endsWith(".sam") || typeString.endsWith(".bam") || typeString.endsWith(".cram") ||
                 typeString.endsWith(".sam.list") || typeString.endsWith(".bam.list") ||
                 typeString.endsWith(".aligned") || typeString.endsWith(".sai") ||
-                typeString.endsWith(".bai") || typeString.endsWith(".csi") ||typeString.equals("alist") ||
+                typeString.endsWith(".bai") || typeString.endsWith(".csi") || typeString.equals("alist") ||
                 typeString.equals(Ga4ghAPIHelper.RESOURCE_TYPE);
     }
 
@@ -366,7 +372,7 @@ public class TrackLoader {
 
 
     private void loadBedPEFile(ResourceLocator locator, List<Track> newTracks, Genome genome) throws IOException {
-        List<BedPEFeature> features = BedPEParser.parse(locator.getPath());
+        BedPEParser.Dataset features = BedPEParser.parse(locator, genome);
         newTracks.add(new InteractionTrack(locator, features, genome));
     }
 
@@ -842,7 +848,7 @@ public class TrackLoader {
 
             // If the user tried to load the index,  look for the file (this is a common mistake)
             if (locator.getTypeString().endsWith(".sai") ||
-                    locator.getTypeString().endsWith(".bai")||
+                    locator.getTypeString().endsWith(".bai") ||
                     locator.getTypeString().endsWith(".csi")) {
                 MessageUtils.showMessage("<html><b>ERROR:</b> Loading SAM/BAM index files are not supported:  " + locator.getPath() +
                         "<br>Load the SAM or BAM file directly. ");
@@ -885,7 +891,7 @@ public class TrackLoader {
             // Skip for GA4GH & SU2C resources
             if (!(Ga4ghAPIHelper.RESOURCE_TYPE.equals(locator.getType()) ||
                     locator.getPath().contains("dataformat=.bam") ||
-                    OAuthUtils.isGoogleCloud(locator.getPath()))) {
+                    GoogleUtils.isGoogleCloud(locator.getPath()))) {
 
                 String covPath = locator.getCoverage();
                 if (covPath == null) {
