@@ -25,15 +25,15 @@
 
 package org.broad.igv.track;
 
-import htsjdk.tribble.AbstractFeatureReader;
-import org.apache.tools.ant.taskdefs.condition.Http;
+import htsjdk.tribble.*;
+import htsjdk.tribble.index.Index;
 import org.broad.igv.Globals;
 import org.broad.igv.data.AbstractDataSource;
 import org.broad.igv.data.DataTile;
-import org.broad.igv.feature.BasicFeature;
 import org.broad.igv.feature.*;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.tribble.*;
+import org.broad.igv.feature.tribble.reader.IGVComponentMethods;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.panel.ReferenceFrame;
 import org.broad.igv.ui.util.IndexCreatorDialog;
@@ -42,9 +42,6 @@ import org.broad.igv.util.HttpUtils;
 import org.broad.igv.util.ResourceLocator;
 import org.broad.igv.util.RuntimeUtils;
 import org.broad.igv.util.collections.CollUtils;
-import org.broad.igv.variant.VariantTrack;
-import htsjdk.tribble.*;
-import htsjdk.tribble.index.Index;
 
 import java.io.File;
 import java.io.IOException;
@@ -74,33 +71,53 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
 
     public static TribbleFeatureSource getFeatureSource(ResourceLocator locator, Genome genome, boolean useCache) throws IOException, TribbleIndexNotFoundException {
 
+        AbstractFeatureReader.setComponentMethods(IGVComponentMethods.getInstance());
+
         FeatureCodec codec = CodecFactory.getCodec(locator, genome);
-        String idxPath = ResourceLocator.indexFile(locator);
-        if(FileUtils.isRemote(idxPath)) {
-            idxPath = HttpUtils.createURL(idxPath).toString();
-        }
-        String path = locator.getPath();
-        if(FileUtils.isRemote(path)) {
-            path = HttpUtils.createURL(path).toString();
+
+        boolean indexExists = false;
+        // Explicit index path
+        String idxPath = locator.getIndexPath();
+        if (idxPath != null) {
+            if (FileUtils.isRemote(idxPath)) {
+                idxPath = HttpUtils.mapURL(idxPath);
+            }
+            indexExists = true;
+        } else {
+            String maybeIdxPath = ResourceLocator.indexFile(locator);
+            if (maybeIdxPath == null) {
+                indexExists = false;
+            } else {
+                if (FileUtils.isRemote(maybeIdxPath)) {
+                    maybeIdxPath = HttpUtils.mapURL(maybeIdxPath);
+                }
+                if(FileUtils.resourceExists(maybeIdxPath)) {
+                    indexExists = true;
+                    idxPath = maybeIdxPath;
+                }
+            }
         }
 
-        boolean indexExists = FileUtils.resourceExists(idxPath);
 
         // Optionally let the user create an index.
         final int hundredMB = 100000000;
         final int oneGB = 1000000000;
         long size = FileUtils.getLength(locator.getPath());
-        final boolean indexRequired =  size > oneGB;
+        final boolean indexRequired = size > oneGB;
         if (!Globals.isHeadless() && locator.isLocal() && !locator.getPath().endsWith(".gz") && !indexExists) {
             if (size > hundredMB) {
                 createIndex(locator, indexRequired);   // Note, might return null.
             }
         }
 
+        String path = locator.getPath();
+        if (FileUtils.isRemote(path)) {
+            path = HttpUtils.mapURL(path);
+        }
         AbstractFeatureReader basicReader = AbstractFeatureReader.getFeatureReader(path, idxPath, codec, indexRequired || indexExists);
 
-        if (basicReader.hasIndex()) {
-            return new IndexedFeatureSource(basicReader, codec, locator, genome, useCache);
+        if (indexExists) { //basicReader.hasIndex()) {
+            return new IndexedFeatureSource(basicReader, codec, locator, genome, true);
         } else {
             return new NonIndexedFeatureSource(basicReader, codec, locator, genome);
         }
@@ -339,9 +356,9 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
         @Override
         public void dispose() {
             super.dispose();
-            for(List<Feature> featureList : featureMap.values()) {
-                for(Feature f : featureList) {
-                    if(f instanceof NamedFeature) FeatureDB.removeFeature((NamedFeature) f, genome);
+            for (List<Feature> featureList : featureMap.values()) {
+                for (Feature f : featureList) {
+                    if (f instanceof NamedFeature) FeatureDB.removeFeature((NamedFeature) f, genome);
                 }
             }
         }
