@@ -31,9 +31,8 @@ import org.broad.igv.Globals;
 import org.broad.igv.annotations.ForTesting;
 import org.broad.igv.charts.ScatterPlotUtils;
 import org.broad.igv.feature.genome.GenomeManager;
-import org.broad.igv.ga4gh.Ga4ghAPIHelper;
-import org.broad.igv.ga4gh.GoogleUtils;
-import org.broad.igv.ga4gh.OAuthUtils;
+import org.broad.igv.google.GoogleUtils;
+import org.broad.igv.google.OAuthUtils;
 import org.broad.igv.gs.GSOpenSessionMenuAction;
 import org.broad.igv.gs.GSSaveSessionMenuAction;
 import org.broad.igv.gs.GSUtils;
@@ -57,7 +56,6 @@ import org.broad.igv.ui.util.*;
 import org.broad.igv.util.BrowserLauncher;
 import org.broad.igv.util.HttpUtils;
 import org.broad.igv.util.LongRunningTask;
-import org.broad.igv.util.ResourceLocator;
 import org.broad.igv.util.blat.BlatClient;
 import org.broad.igv.util.encode.EncodeFileBrowser;
 
@@ -288,9 +286,6 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
         String genomeId = IGV.getInstance().getGenomeManager().getGenomeId();
         encodeMenuItem.setVisible (EncodeFileBrowser.genomeSupported(genomeId));
 
-
-        menuAction = new BrowseGa4ghAction("Load from Ga4gh...", KeyEvent.VK_G, igv);
-        menuItems.add(MenuAndToolbarUtils.createMenuItem(menuAction));
         menuItems.add(new JSeparator());
 
         // Session menu items
@@ -299,7 +294,7 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
         menuItems.add(MenuAndToolbarUtils.createMenuItem(menuAction));
 
         menuAction = new OpenSessionMenuAction("Open Session...", KeyEvent.VK_O, igv);
-        menuAction.setToolTipText(UIConstants.RESTORE_SESSION_TOOLTIP);
+        menuAction.setToolTipText(OPEN_SESSION_TOOLTIP);
         menuItems.add(MenuAndToolbarUtils.createMenuItem(menuAction));
 
         menuAction = new SaveSessionMenuAction("Save Session...", KeyEvent.VK_V, igv);
@@ -307,6 +302,11 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
         JMenuItem saveSessionItem = MenuAndToolbarUtils.createMenuItem(menuAction);
         menuItems.add(saveSessionItem);
 
+        menuAction = new ReloadSessionMenuAction("Reload Session", -1, igv);
+        menuAction.setToolTipText(RELOAD_SESSION_TOOLTIP);
+        JMenuItem reloadSessionItem = MenuAndToolbarUtils.createMenuItem(menuAction);
+        menuItems.add(reloadSessionItem);
+
         menuItems.add(new JSeparator());
 
         // ***** Snapshots
@@ -991,19 +991,6 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
         projectID.addActionListener(e -> GoogleUtils.enterGoogleProjectID());
         menu.add(projectID);
 
-        final JMenuItem loadReadset = new JMenuItem("Load Genomics ReadGroupSet... ");
-        loadReadset.addActionListener(e -> {
-            String readsetId = MessageUtils.showInputDialog("Enter ReadGroupSet ID (e.g. CMvnhpKTFhCjz9_25e_lCw): ");
-            if (readsetId != null) {
-                ResourceLocator locator = new ResourceLocator(readsetId);
-                locator.setName(readsetId);
-                locator.setType(Ga4ghAPIHelper.RESOURCE_TYPE);
-                locator.setAttribute("provider", Ga4ghAPIHelper.GA4GH_GOOGLE_PROVIDER);
-                IGV.getInstance().loadTracks(Arrays.asList(locator));
-            }
-        });
-        loadReadset.setEnabled(false);
-        menu.add(loadReadset);
 
         menu.addMenuListener(new MenuListener() {
             @Override
@@ -1017,7 +1004,6 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
                     }
                     login.setEnabled(!loggedIn);
                     logout.setEnabled(loggedIn);
-                    loadReadset.setEnabled(loggedIn);
                 };
 
                 LongRunningTask.submit(runnable);
