@@ -108,7 +108,7 @@ public class RulerPanel extends JPanel {
 
         super.paintComponent(g);
 
-        if (PreferencesManager.getPreferences().getAsBoolean(ENABLE_ANTIALISING)) {
+        if (PreferencesManager.getPreferences().getAntiAliasing()) {
             ((Graphics2D) g).setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
         }
 
@@ -271,10 +271,10 @@ public class RulerPanel extends JPanel {
             if (dw > 5) {
                 int center = x + dw / 2;
 
-                String displayName = null;
+                String displayName = chrName;
                 if (chrName.startsWith("gi|")) {
                     displayName = Genome.getNCBIName(chrName);
-                } else {
+                } else if (chrName.length() < 6) {
                     displayName = chrName.replace("chr", "");
                 }
                 int strWidth = fontMetrics.stringWidth(displayName);
