@@ -26,17 +26,14 @@
 package org.broad.igv.util;
 
 import org.apache.commons.io.FilenameUtils;
-import org.apache.commons.io.filefilter.WildcardFileFilter;
 import org.apache.commons.io.output.StringBuilderWriter;
 import org.apache.log4j.Logger;
 import org.broad.igv.util.ftp.FTPUtils;
 
 import java.io.*;
 import java.net.URL;
-import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Comparator;
-import java.util.List;
 import java.util.regex.Pattern;
 
 /**
@@ -247,6 +244,35 @@ public class FileUtils {
         }
     }
 
+    /**
+     * Return the first line not starting with commentChar
+     *
+     * @param path
+     * @param commentChar
+     * @return
+     * @throws IOException
+     */
+    public static String getFirstLine(String path, String commentChar) throws IOException {
+
+        if(path == null) return null;
+
+        BufferedReader reader = null;
+        try {
+            reader = ParsingUtils.openBufferedReader(path);
+            String nextLine;
+            while ((nextLine = reader.readLine()) != null) {
+                if (commentChar != null && nextLine.startsWith(commentChar)) {
+                    continue;
+                }
+                return nextLine;
+            }
+            return null;
+        } finally {
+            if (reader != null) {
+                reader.close();
+            }
+        }
+    }
 
     /**
      * Copy a file from one location to another, using buffered writing
