@@ -36,7 +36,6 @@ import org.broad.igv.feature.IGVFeature;
 import org.broad.igv.prefs.IGVPreferences;
 import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.renderer.GraphicUtils;
-import org.broad.igv.session.IGVSessionReader;
 
 import org.broad.igv.track.*;
 import org.broad.igv.ui.FontManager;
@@ -234,7 +233,7 @@ public class VariantTrack extends FeatureTrack implements IGVEventObserver {
 
         boolean bypassFileAutoDiscovery = prefMgr.getAsBoolean(BYPASS_FILE_AUTO_DISCOVERY);
         if (vcfToBamMapping == null && path != null && !bypassFileAutoDiscovery) {
-            if (ParsingUtils.pathExists(path + ".mapping")) {
+            if (ParsingUtils.fileExists(path + ".mapping")) {
                 vcfToBamMapping = path + ".mapping";
             }
         }
@@ -1452,6 +1451,9 @@ public class VariantTrack extends FeatureTrack implements IGVEventObserver {
             while ((f = super.nextFeature(chr, center, forward, frame)) != null) {
                 if (!(f instanceof Variant) || !((Variant) f).isFiltered()) {
                     return f;
+                } else {
+                    chr = f.getChr();
+                    center = (f.getStart() + f.getEnd()) / 2 + 1;
                 }
             }
             return null;
